mhurl

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: BSD-3-Clause Imports: 5 Imported by: 0

README

MHURL

Go Reference

parses URLs support multiple hosts.

Copy and modify from https://github.com/golang/go/blob/go1.26.1/src/net/url/url.go

The reason is that the origin Parse() func does not support multiple hosts in the Host part after Go 1.26. See the original issue for more details:

Documentation

Overview

Package mhurl parses URLs support multiple hosts.

Copy and modify from https://github.com/golang/go/blob/go1.26.1/src/net/url/url.go The reason is that the origin `Parse()` func does not support multiple hosts in the Host part after Go 1.26. See the original issue for more details:

https://github.com/golang/go/issues/75859
https://github.com/golang/go/issues/78077

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Parse

func Parse(rawURL string) (*neturl.URL, error)

Parse parses a raw url into a [URL] structure.

The url may be relative (a path, without a host) or absolute (starting with a scheme). Trying to parse a hostname and path without a scheme is invalid but may not necessarily return an error, due to parsing ambiguities.

Types

This section is empty.

Jump to